from pyDobotMagician import dobotMagician
import sys
import time

def showStatus(dobot):
    s=dobot.getAllStatus()
    for a,b in s.items():
        print(a,": ",b,sep="")
    print()

def showAlarms(dobot,s):
    if len(s)==0:
        print("No alarm")
    else:
        print("Alarms:")
    for i in s:
        if i==-1:
            print("Get Alarm State error.")
        elif i in dobot.alarmState:
            print("--",dobot.alarmState[i])
        else:
            print("--error code ",i)

# Creates an instance of Dobot Magician
bot = dobotMagician(False) # False=Normal mode, True=Debug mode

# n=bot.connect()  Auto scan com ports
# n=bot.connect("COM3")  Set specific serial port, parameter="COM3"
# Success: return ''
# Fail: return error message
error=bot.connect("COM3")
if error!='':
    print(error)
    sys.exit("Dobot not found.")

# reset the Dobot parameters
bot.reset()

# check if there is any alarm state
alarms=bot.getAlarmState()
if len(alarms)>0:
    showAlarms(bot,alarms)
    sys.exit("Dobot alarm detected.")
print("No alarm detected.")

# show the Dobot status
showStatus(bot)

# This must be the first movement command to
# reset the servo motors to follow proper coordinates.
bot.setToHome()
pose=bot.getPose()
print("Pose x={:.2f} y={:.2f} z={:.2f} r={:.2f}".format(pose[0],pose[1],pose[2],pose[3]))
print("Pose j1={:.2f} j2={:.2f} j3={:.2f} j4={:.2f}".format(pose[4],pose[5],pose[6],pose[7]))
print("Queue index: ",bot.getQueuedCmdCurrentIndex())
input("press enter to continue")
print()

# move to absolute x,y,z coordinates
##bot.setPTPCmd(260,-50,-20,0)
##print("Pose x={:.2f} y={:.2f} z={:.2f} r={:.2f}".format(pose[0],pose[1],pose[2],pose[3]))
##print("Pose j1={:.2f} j2={:.2f} j3={:.2f} j4={:.2f}".format(pose[4],pose[5],pose[6],pose[7]))
##print("Queue index: ",bot.getQueuedCmdCurrentIndex())
##input("press enter to continue")
##print()

# relative movement
##bot.moveDistance(-10,50,20)
##print("Pose x={:.2f} y={:.2f} z={:.2f} r={:.2f}".format(pose[0],pose[1],pose[2],pose[3]))
##print("Pose j1={:.2f} j2={:.2f} j3={:.2f} j4={:.2f}".format(pose[4],pose[5],pose[6],pose[7]))
##print("Queue index: ",bot.getQueuedCmdCurrentIndex())
##input("press enter to continue")
##print()

# arc
bot.setPTPCmd(250,-20,50,0,bot.MOVJ_XYZ)
bot.setArcCmd(270,0,50,0,220,0,50,0)
pose=bot.getPose()
print("Pose x={:.2f} y={:.2f} z={:.2f} r={:.2f}".format(pose[0],pose[1],pose[2],pose[3]))
print("Pose j1={:.2f} j2={:.2f} j3={:.2f} j4={:.2f}".format(pose[4],pose[5],pose[6],pose[7]))
print("Queue index: ",bot.getQueuedCmdCurrentIndex())
input("press enter to continue")
print()

# arc
# from current point A, pass through intermediate point B to end point C.
# A, B and C cannot be on a straight line
# if A and C are opposite points on a diameter, drawing a semi-circle is not guaranteed
bot.setPTPCmd(250,0,50,0,bot.MOVJ_XYZ)
bot.setArcCmd(270,-20,50,0,290,0,50,0) # fail to draw this semi-circle without alarm state
alarms=bot.getAlarmState()
if len(alarms)>0:
    showAlarms(bot,alarms)
    sys.exit("Dobot alarm detected.")
print("No alarm detected.")
pose=bot.getPose()
print("Pose x={:.2f} y={:.2f} z={:.2f} r={:.2f}".format(pose[0],pose[1],pose[2],pose[3]))
print("Pose j1={:.2f} j2={:.2f} j3={:.2f} j4={:.2f}".format(pose[4],pose[5],pose[6],pose[7]))
print("Queue index: ",bot.getQueuedCmdCurrentIndex())
input("press enter to continue")
print()

##bot.setPTPCmd(289,0,50,0,bot.MOVJ_XYZ)
bot.setPTPCmd(290,0,50,0,bot.MOVJ_XYZ) # fail to draw this semi-circle without alarm state
bot.setArcCmd(270,20,50,0,250,0,50,0)
alarms=bot.getAlarmState()
if len(alarms)>0:
    showAlarms(bot,alarms)
    sys.exit("Dobot alarm detected.")
print("No alarm detected.")
pose=bot.getPose()
print("Pose x={:.2f} y={:.2f} z={:.2f} r={:.2f}".format(pose[0],pose[1],pose[2],pose[3]))
print("Pose j1={:.2f} j2={:.2f} j3={:.2f} j4={:.2f}".format(pose[4],pose[5],pose[6],pose[7]))
print("Queue index: ",bot.getQueuedCmdCurrentIndex())
input("press enter to continue")
print()

# Disconnect the Dobot
bot.disconnect()

print("Test finished.")
